import type { TesApiHanParams } from './types';
/**
 * Uses Next's internal `apiResolver` to execute api route handlers in a
 * Next-like testing environment.
 *
 * @param test should be a function that returns a promise (or async) where test
 * assertions can be run. This function receives one parameter: fetch, which is
 * unfetch's `fetch(...)` function but with the first parameter omitted.
 *
 * @param params are passed directly to the api handler and represent processed
 * dynamic routes. This should not be confused with query string parsing, which
 * is handled automatically.
 *
 * @param requestPatcher/responsePatcher are functions that receive an
 * IncomingMessage and ServerResponse object respectively. Use these functions
 * to edit the request and response before they're injected into the api
 * handler.
 *
 * @param handler is the actual api handler under test. It should be an async
 * function that accepts NextApiRequest and NextApiResult objects (in that
 * order) as its two parameters.
 */
export declare function testApiHandler({ test, params, requestPatcher, responsePatcher, handler }: TesApiHanParams): Promise<void>;
